.. include:: /_includes/wip_prolog.rst

:mod:`stix.data_marking` Module
==================================

.. module:: stix.data_marking

Classes
-------

.. autoclass:: Marking
	:show-inheritance:
	:members:

.. autoclass:: MarkingSpecification
	:show-inheritance:
	:members:

.. autoclass:: MarkingStructure
	:show-inheritance:
	:members:

Functions
---------

.. autofunction:: add_extension

Constants
---------

.. autodata:: _EXTENSION_MAP
